@@ -1,5 +1,6 @@
 import time
 import warnings
+from base64 import decodestring
 
 try:
     import requests
@@ -34,6 +35,8 @@ class RequestsHttpConnection(Connection):
     :arg client_key: path to the file containing the private key if using
         separate cert and key files (client_cert will contain only the cert)
     :arg headers: any custom http headers to be add to requests
+    :arg cloud_id: The Cloud ID from ElasticCloud. Convient way to connect to cloud instances.
+        Other host connection params will be ignored.
     """
 
     def __init__(
@@ -48,12 +51,21 @@ class RequestsHttpConnection(Connection):
         client_cert=None,
         client_key=None,
         headers=None,
+        cloud_id=None,
         **kwargs
     ):
         if not REQUESTS_AVAILABLE:
             raise ImproperlyConfigured(
                 "Please install requests to use RequestsHttpConnection."
             )
+        if cloud_id:
+            cluster_name, cloud_id = cloud_id.split(":")
+            url, es_uuid, kibana_uuid = (
+                decodestring(cloud_id.encode("utf-8")).decode("utf-8").split("$")
+            )
+            host = "%s.%s" % (es_uuid, url)
+            port = 9243
+            use_ssl = True
 
         super(RequestsHttpConnection, self).__init__(
             host=host, port=port, use_ssl=use_ssl, **kwargs
@@ -61,6 +73,7 @@ class RequestsHttpConnection(Connection):
         self.session = requests.Session()
         self.session.headers = headers or {}
         self.session.headers.setdefault("content-type", "application/json")
+        self.session.headers.setdefault("user-agent", self._get_default_user_agent())
         if http_auth is not None:
             if isinstance(http_auth, (tuple, list)):
                 http_auth = tuple(http_auth)
